@@ -5,7 +5,7 @@ import regex as re
 import nltk
 import os
 
-if not os.path.exist(str(Path(__file__).parent) +'/saved/corpora/wordnet'):
+if not os.path.exists(str(Path(__file__).parent) +'/saved/corpora/wordnet'):
 	nltk.download('wordnet', download_dir=str(Path(__file__).parent) +'/saved')
 else:
      nltk.data.path.append(str(Path(__file__).parent) +'/saved/corpora/wordnet')
